package com.gic.demo.project.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.demo.project.api.dto.DemoStoreDTO;
import com.gic.demo.project.api.service.DemoStoreApiService;
import com.gic.demo.project.web.exception.GicDemoErrCode;
import com.gic.demo.project.web.vo.DemoStoreVO;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 指标管理接口
 *
 * @author zhurz
 */
@RestController
@RequestMapping("/demo")
public class DemoProjectController {

    private static final Logger logger = LoggerFactory.getLogger(DemoProjectController.class);

    @Autowired
    private DemoStoreApiService demoStoreApiService;

    /**
     * 获取门店信息
     *
     * @param storeId 门店id
     * @return
     */
    @RequestMapping("/get-store-info")
    public RestResponse getStoreInfo(String storeId) {
        if (StringUtils.isBlank(storeId)) {
            return GicDemoErrCode.ERR_2.buildFailureResponse();
        }
        ServiceResponse<DemoStoreDTO> response = demoStoreApiService.findDemoStoreById(storeId);
        if (response.isSuccess()) {
            // 转换为VO
            DemoStoreVO vo = EntityUtil.changeEntityByOrika(DemoStoreVO.class, response.getResult());
            return RestResponse.success(vo);
        }
        logger.warn("获取门店信息异常 -> {} -> {}", storeId, response.getMessage());
        return GicDemoErrCode.ERR_1.buildFailureResponse();
    }
}